@@ -5,10 +5,10 @@ CREATE OR REPLACE FUNCTION PC_Intersection(pcpatch, geometry)
 	RETURNS pcpatch AS
 	$$
 		WITH
-			 pts AS (SELECT PC_Explode($1) AS pt),
-		   pgpts AS (SELECT ST_GeomFromEWKB(PC_AsBinary(pt)) AS pgpt, pt FROM pts),
-			ipts AS (SELECT pt FROM pgpts WHERE ST_Intersects(pgpt, $2)),
-			ipch AS (SELECT PC_Patch(pt) AS pch FROM ipts)
+			 pts AS (SELECT @extschema@.PC_Explode($1) AS pt),
+		   pgpts AS (SELECT @extschema@.ST_GeomFromEWKB(@extschema@.PC_AsBinary(pt)) AS pgpt, pt FROM pts),
+			ipts AS (SELECT pt FROM pgpts WHERE @extschema@.ST_Intersects(pgpt, $2)),
+			ipch AS (SELECT @extschema@.PC_Patch(pt) AS pch FROM ipts)
 		SELECT pch FROM ipch;
 	$$
 	LANGUAGE 'sql';
@@ -19,14 +19,14 @@ CREATE OR REPLACE FUNCTION PC_Intersection(pcpatch, geometry)
 CREATE OR REPLACE FUNCTION PC_EnvelopeGeometry(pcpatch)
 	RETURNS geometry AS
 	$$
-		SELECT ST_GeomFromEWKB(PC_EnvelopeAsBinary($1))
+		SELECT @extschema@.ST_GeomFromEWKB(@extschema@.PC_EnvelopeAsBinary($1))
 	$$
 	LANGUAGE 'sql';
 
 CREATE OR REPLACE FUNCTION geometry(pcpatch)
 	RETURNS geometry AS
 	$$
-		SELECT PC_EnvelopeGeometry($1)
+		SELECT @extschema@.PC_EnvelopeGeometry($1)
 	$$
 	LANGUAGE 'sql';
 
@@ -39,7 +39,7 @@ CREATE CAST (pcpatch AS geometry) WITH FUNCTION PC_EnvelopeGeometry(pcpatch);
 CREATE OR REPLACE FUNCTION geometry(pcpoint)
 	RETURNS geometry AS
 	$$
-		SELECT ST_GeomFromEWKB(PC_AsBinary($1))
+		SELECT @extschema@.ST_GeomFromEWKB(@extschema@.PC_AsBinary($1))
 	$$
 	LANGUAGE 'sql';
 
@@ -52,14 +52,14 @@ CREATE CAST (pcpoint AS geometry) WITH FUNCTION geometry(pcpoint);
 CREATE OR REPLACE FUNCTION PC_Intersects(pcpatch, geometry)
 	RETURNS boolean AS
 	$$
-		SELECT ST_Intersects($2, PC_EnvelopeGeometry($1))
+		SELECT @extschema@.ST_Intersects($2, @extschema@.PC_EnvelopeGeometry($1))
 	$$
 	LANGUAGE 'sql';
 
 CREATE OR REPLACE FUNCTION PC_Intersects(geometry, pcpatch)
 	RETURNS boolean AS
 	$$
-		SELECT PC_Intersects($2, $1)
+		SELECT @extschema@.PC_Intersects($2, $1)
 	$$
 	LANGUAGE 'sql';
 
@@ -69,7 +69,7 @@ CREATE OR REPLACE FUNCTION PC_Intersects(geometry, pcpatch)
 CREATE OR REPLACE FUNCTION PC_BoundingDiagonalGeometry(pcpatch)
 	RETURNS geometry AS
 	$$
-		SELECT ST_GeomFromEWKB(PC_BoundingDiagonalAsBinary($1))
+		SELECT @extschema@.ST_GeomFromEWKB(@extschema@.PC_BoundingDiagonalAsBinary($1))
 	$$
 	LANGUAGE 'sql';
 
@@ -77,5 +77,5 @@ CREATE OR REPLACE FUNCTION PC_BoundingDiagonalGeometry(pcpatch)
 -- Function returning the version number
 --
 CREATE OR REPLACE FUNCTION PC_PostGIS_Version()
-	RETURNS text AS $$ SELECT '1.2.1'::text $$
+	RETURNS text AS $$ SELECT '1.2.2'::text $$
 	LANGUAGE 'sql' IMMUTABLE STRICT;
